is_interrupt

Function is_interrupt 

pub fn is_interrupt(
    ctx: &Context<'static>,
    insn: InstructionId,
    code: u64,
    arg: Option<u64>,
) -> bool
Whether insn is a VM_INTERRUPT whose first operand is the literal code and, when arg is given, whose second is the literal arg.